@@ -1,10 +1,11 @@
 
 use super::*;
+use super::event::*;
 
 mod goal;
 mod read;
 mod parse;
 
-pub(crate) use parse::*;
-pub(crate) use read::*;
+pub use parse::*;
+pub use read::*;
 pub use goal::*;
