@@ -7,7 +7,7 @@ use std::path::PathBuf;
 use std::fmt::{ Debug, Display, Formatter };
 use std::any::{ TypeId, Any };
 use std::ops::Range;
-use crossterm::*;
+use crossterm::QueueableCommand;
 use crossterm::style::*;
 use std::ops::Index;
 use std::io::stdout;
@@ -17,21 +17,23 @@ use std::collections::BTreeSet;
 use std::borrow::BorrowMut;
 use std::path::Path;
 use std::fs::read_to_string;
+use std::time::*;
 
 type Result<T> = std::result::Result<T,()>;
 
-mod place;
 mod event;
+
 mod goal;
-mod span;
+mod place;
 mod page;
 mod state;
 mod status;
+mod receipt;
 
-pub use span::*;
+pub use goal::Goal;
+pub use event::Event;
+pub use receipt::*;
 pub use place::*;
-pub use event::*;
-pub use goal::*;
 pub use page::*;
 pub use state::*;
 pub use status::*;
@@ -57,11 +59,11 @@ mod tests {
 		let other_event = state.start_parse::<usize>();
 
 		let description = "Something succeeded.".to_string();
-		state.finish_event(other_event, Status::Success(description));
+		state.end_event(other_event, Status::Success(description));
 		
 		state.advance(1)?;
 		
-		state.finish_event(event, Status::Error("Oh no - something happened.".to_string()));
+		state.end_event(event, Status::Error("Oh no - something happened.".to_string()));
 
 		for event in state.history() {
 
