@@ -8,7 +8,6 @@ pub enum Status {
 	Warning(String),
 	Error(String),
 	Note(String),
-	Unfinished
 	
 }
 
@@ -41,13 +40,6 @@ impl Status {
 		matches!(self, Self::Note(_))
 		
 	}
-	
-	/// Whether `self` is `Self::Unfinished`.
-	pub fn is_unfinished(&self) -> bool {
-
-		matches!(self, Self::Unfinished)
-
-	}
 
 	pub(crate) fn color(&self) -> Color {
 
@@ -57,7 +49,6 @@ impl Status {
 			Self::Error(_) => Color::Red,
 			Self::Note(_) => Color::Blue,
 			Self::Success(_) => Color::Green,
-			Self::Unfinished => Color::White,
 
 		}
 
@@ -71,7 +62,6 @@ impl Status {
 			Self::Error(description) => &description,
 			Self::Note(description) => &description,
 			Self::Success(description) => &description,
-			Self::Unfinished => ""
 
 		}
 
